%
% Use model series to test "regression and removal" approach
%
% read in EBM simulations of global mean temp 1000-1835 CE
% based on two different combinations of rorc
% as used in Mann et al (2021) Science article
%
load matrixtemp_schmidt_GRA_VSK.dat
load matrixtemp_schmidt_CEA_SBF.dat
year=matrixtemp_schmidt_GRA_VSK(:,1);
globe1=matrixtemp_schmidt_GRA_VSK(:,2);
globe2=matrixtemp_schmidt_CEA_SBF(:,2);
%
% now read CESM 13 realization ensemble global mean
% use overlap interval of 1000-1835 CE
%
load CESM_LME_global_mean_series.dat
globe3=CESM_LME_global_mean_series(151:986,2);
%
% recenter to match EBM simulations
globe3=globe3+mean(globe1)-mean(globe3);
cesmm=globe3;
%
% calculate multidecadally-smoothed CESM ensemble mean global series
% (smooth on timescales > 40 years)
freq=0.025;
%
[smoothedcesmm,w0,w1,w2,msebest] = lowpassadaptive(cesmm,freq);
%
figure(1)
hold
plot(year,globe1)
plot(year,globe2,'r')
plot(year,globe3,'k')
%
frequency=1/15.0;
indata1=globe1;
indata2=globe2;
indata3=globe3;
[smoothed1,w0,w1,w2,msebest] = lowpassadaptive(indata1,frequency);
[smoothed2,w0,w1,w2,msebest] = lowpassadaptive(indata2,frequency);
[smoothed3,w0,w1,w2,msebest] = lowpassadaptive(indata3,frequency);
%
figure(2)
hold
plot(year,smoothed1)
plot(year,smoothed2,'r')
plot(year,smoothed3,'k')
%
% use regional regression to estimate forced signal contained by smoothed series 2) in
% (raw) series1
%
N=length(year);
Y = globe1;
wons=ones(N,1);
X = [smoothed2 wons];
[B,BINT,R,RINT,STATS] = regress(Y,X);
ymodel1=B(1)*X(:,1)+B(2);
%
resid1=Y-ymodel1;
freq=0.025;
[smoothedresid1,w0,w1,w2,msebest] = lowpassadaptive(resid1,freq);
%
figure(3)
hold
plot(year,resid1)
plot(year,smoothedresid1,'r')
%
%
% use regional regression to estimate forced signal contained by smoothed series 1) in
% (raw) series2
%
Y = globe2;
X = [smoothed1 wons];
[B,BINT,R,RINT,STATS] = regress(Y,X);
ymodel2=B(1)*X(:,1)+B(2);
%
resid2=Y-ymodel2;
[smoothedresid2,w0,w1,w2,msebest] = lowpassadaptive(resid2,freq);
%
figure(4)
hold
plot(year,resid2)
plot(year,smoothedresid2,'r')
%
%
% use regional regression to estimate forced signal contained by smoothed series 3) in
% (raw) series2
%
Y = globe2;
X = [smoothed3 wons];
[B,BINT,R,RINT,STATS] = regress(Y,X);
ymodel3=B(1)*X(:,1)+B(2);
%
resid3=Y-ymodel3;
[smoothedresid3,w0,w1,w2,msebest] = lowpassadaptive(resid3,freq);
%
figure(5)
hold
plot(year,resid3)
plot(year,smoothedresid3,'r')
%
%
%
%
% now analyze individual CESM realizations%
%
% read in each of the CESM 13 realization ensemble global mean
% use overlap interval of 1000-1835 CE
%
% define "true" forced response as 15 year lowpassed EBM-simulated global mean
% temp response to CEA/SBF forcing (with ECS=3.0)
globetrue=smoothed2;
load CESM_LME_GlobalAnnualMean_Ensembles.dat
%
%
%
freq=0.025;
%
for i=1:13
cesm(:,i) = CESM_LME_GlobalAnnualMean_Ensembles(151:986,i+1);
cesm(:,i)=cesm(:,i)-mean(cesm(:,i));
indata1=cesm(:,i);
[smoothedcesm(:,i),w0,w1,w2,msebest] = lowpassadaptive(indata1,freq);
%
% remove estimated radiative forcing using ensemble mean
%
cesmintern(:,i) = cesm(:,i)-cesmm;
%plot(year,cesmintern1)
[smoothedintern(:,i),w0,w1,w2,msebest] = lowpassadaptive(cesmintern(:,i),freq);
%
% now attempt to remove radiative forcing using regression-based method based on
% use of CES/SBF EBM-based global mean temperature (series 2) as estimate
% of forced signal in CESM ensemble series
%
Y = cesm(:,i);
X = [globetrue wons];
[B,BINT,R,RINT,STATS] = regress(Y,X);
ymodelcesm(:,i)=B(1)*X(:,1)+B(2);
%
residcesm(:,i)=Y-ymodelcesm(:,i);
[smoothedresid(:,i),w0,w1,w2,msebest] = lowpassadaptive(residcesm(:,i),freq);
end
%
resids1=[year residcesm(:,1) residcesm(:,2) residcesm(:,3) residcesm(:,4)];
interns1=[year cesmintern(:,1) cesmintern(:,2) cesmintern(:,3) cesmintern(:,4)];
save -ascii 'resids1.dat' resids1
save -ascii 'interns1.dat' interns1
%
resids2=[year residcesm(:,5) residcesm(:,6)];
interns2=[year cesmintern(:,5) cesmintern(:,6)];
save -ascii 'resids2.dat' resids2
save -ascii 'interns2.dat' interns2
%
%
% FIGURE COMPARING THE THREE ESTIMATES OF GLOBAL FORCED VARIABILITY
%
figure(7)
hold
title('Forced Global Temperatures')
set(gca,'FontSize',14);
hline1=plot(year,smoothed1,'k','Linewidth',1.5);
hline2=plot(year,smoothed2,'r','Linewidth',1.5);
%
% since regression procedure automatically accounts for different overall
% amplitudes, rescale CESM mean so it has same variance as EBM simulation
% driven by same forcings (GRA/VSK)
%
adjustscale=std(smoothed1)/std(smoothed3);
smoothed3adjusted=smoothed3*adjustscale;
%
%
hline3=plot(year,smoothed3adjusted,'b','Linewidth',1.5);
ylabel('Temperature Anomaly(^oC)');
xlabel('Year'); 
set(gca,'YLim',[-2.5 1.0])
set(gca,'XLim',[1000 1835])
legend([hline1 hline2 hline3],'EBM-GRA/VSK','EBM-CEA/SBF','CESM ensemble mean');
%
%
% FIGURE COMPARING ESTIMATES OF INTERNAL VARIABILITY
%
figure(8)
h1=subplot(3,2,1); % all simulations
set(gca, 'OuterPosition', [0, 0.67, 0.49, 0.33])
hold
plot(year,smoothedcesm(:,1),'r');
plot(year,smoothedcesmm,'g','linewidth',2);
plot(year,smoothedintern(:,1),'k','linewidth',2);
plot(year,smoothedresid(:,1),'b');
set(gca,'YLim',[-0.3 0.3])
set(gca,'XLim',[1000 1835])
ylabel('Temp Anom(^oC)');
%
h2=subplot(3,2,2); % CMIP5 multimodel zonal means - AIE-only simulations
set(gca, 'OuterPosition', [0.48, 0.67, 0.49, 0.33])
hold
plot(year,smoothedcesm(:,2),'r');
plot(year,smoothedcesmm,'g','linewidth',2);
plot(year,smoothedintern(:,2),'k','linewidth',2);
plot(year,smoothedresid(:,2),'b');
set(gca,'YLim',[-0.3 0.3])
set(gca,'XLim',[1000 1835])
%
h3=subplot(3,2,3); % CMIP5 multimodel high lat & global series - all models
set(gca, 'OuterPosition', [0, 0.33, 0.49, 0.33])
hold
plot(year,smoothedcesm(:,3),'r');
plot(year,smoothedcesmm,'g','linewidth',2);
plot(year,smoothedintern(:,3),'k','linewidth',2);
plot(year,smoothedresid(:,3),'b');
set(gca,'YLim',[-0.3 0.3])
set(gca,'XLim',[1000 1835])
ylabel('Temp Anom(^oC)');
%
h4=subplot(3,2,4); % CMIP5 multimodel high lat & global series - AIE-only simulatons
set(gca, 'OuterPosition', [0.48, 0.33, 0.49, 0.33])
hold
plot(year,smoothedcesm(:,4),'r');
plot(year,smoothedcesmm,'g','linewidth',2);
plot(year,smoothedintern(:,4),'k','linewidth',2);
plot(year,smoothedresid(:,4),'b');
set(gca,'YLim',[-0.3 0.3])
set(gca,'XLim',[1000 1835])
%
h5=subplot(3,2,5); % CMIP5 multimodel AA series - all models
set(gca, 'OuterPosition', [0, 0.0, 0.49, 0.33])
hold
plot(year,smoothedcesm(:,5),'r');
plot(year,smoothedcesmm,'g','linewidth',2);
plot(year,smoothedintern(:,5),'k','linewidth',2);
plot(year,smoothedresid(:,5),'b');
set(gca,'YLim',[-0.3 0.3])
set(gca,'XLim',[1000 1835])
%
h6=subplot(3,2,6); % CMIP5 multimodel AA series - AIE-only simulatons
set(gca, 'OuterPosition', [0.48, 0.0, 0.49, 0.33])
hold
plot(year,smoothedcesm(:,6),'r');
plot(year,smoothedcesmm,'g','linewidth',2);
plot(year,smoothedintern(:,6),'k','linewidth',2);
plot(year,smoothedresid(:,6),'b');
set(gca,'YLim',[-0.3 0.3])
set(gca,'XLim',[1000 1835])
%
%
%
% FIGURE COMPARING ESTIMATES OF INTERNAL VARIABILITY
%
figure(9)
%
%
h1=subplot(3,2,1); % all simulations
set(gca, 'OuterPosition', [0, 0.67, 0.49, 0.33])
load spec-raw-resid1.dat
load spec-conf-resid1.dat
fr=spec_raw_resid1(:,1);
psd=spec_raw_resid1(:,2);
semilogy(fr,psd,'g')
hold
load spec-raw-intern1.dat
load spec-conf-intern1.dat
fr=spec_raw_intern1(:,1);
psd=spec_raw_intern1(:,2);
psd50=spec_conf_intern1(:,2);
psd90=spec_conf_intern1(:,3);
psd95=spec_conf_intern1(:,4);
semilogy(fr,psd,'k')
semilogy(fr,psd50,'r-')
semilogy(fr,psd90,'r-')
semilogy(fr,psd95,'r-')
set(gca,'YLim',[0.5 300])
%
h2=subplot(3,2,2); % CMIP5 multimodel zonal means - AIE-only simulations
set(gca, 'OuterPosition', [0.48, 0.67, 0.49, 0.33])
load spec-raw-resid2.dat
load spec-conf-resid2.dat
fr=spec_raw_resid2(:,1);
psd=spec_raw_resid2(:,2);
semilogy(fr,psd,'g')
hold
load spec-raw-intern2.dat
load spec-conf-intern2.dat
fr=spec_raw_intern2(:,1);
psd=spec_raw_intern2(:,2);
psd50=spec_conf_intern2(:,2);
psd90=spec_conf_intern2(:,3);
psd95=spec_conf_intern2(:,4);
semilogy(fr,psd,'k')
semilogy(fr,psd50,'r-')
semilogy(fr,psd90,'r-')
semilogy(fr,psd95,'r-')
set(gca,'YLim',[0.5 300])
%
h3=subplot(3,2,3); % CMIP5 multimodel high lat & global series - all models
set(gca, 'OuterPosition', [0, 0.33, 0.49, 0.33])
load spec-raw-resid3.dat
load spec-conf-resid3.dat
fr=spec_raw_resid3(:,1);
psd=spec_raw_resid3(:,2);
semilogy(fr,psd,'g')
hold
load spec-raw-intern3.dat
load spec-conf-intern3.dat
fr=spec_raw_intern3(:,1);
psd=spec_raw_intern3(:,2);
psd50=spec_conf_intern3(:,2);
psd90=spec_conf_intern3(:,3);
psd95=spec_conf_intern3(:,4);
semilogy(fr,psd,'k')
semilogy(fr,psd50,'r-')
semilogy(fr,psd90,'r-')
semilogy(fr,psd95,'r-')
set(gca,'YLim',[0.5 300])
%
h4=subplot(3,2,4); % CMIP5 multimodel high lat & global series - AIE-only simulatons
set(gca, 'OuterPosition', [0.48, 0.33, 0.49, 0.33])
load spec-raw-resid4.dat
load spec-conf-resid4.dat
fr=spec_raw_resid4(:,1);
psd=spec_raw_resid4(:,2);
semilogy(fr,psd,'g')
hold
load spec-raw-intern4.dat
load spec-conf-intern4.dat
fr=spec_raw_intern4(:,1);
psd=spec_raw_intern4(:,2);
psd50=spec_conf_intern4(:,2);
psd90=spec_conf_intern4(:,3);
psd95=spec_conf_intern4(:,4);
semilogy(fr,psd,'k')
semilogy(fr,psd50,'r-')
semilogy(fr,psd90,'r-')
semilogy(fr,psd95,'r-')
set(gca,'YLim',[0.5 300])
%
h5=subplot(3,2,5); % CMIP5 multimodel AA series - all models
set(gca, 'OuterPosition', [0, 0.0, 0.49, 0.33])
load spec-raw-resid5.dat
load spec-conf-resid5.dat
fr=spec_raw_resid5(:,1);
psd=spec_raw_resid5(:,2);
semilogy(fr,psd,'g')
hold
load spec-raw-intern5.dat
load spec-conf-intern5.dat
fr=spec_raw_intern5(:,1);
psd=spec_raw_intern5(:,2);
psd50=spec_conf_intern5(:,2);
psd90=spec_conf_intern5(:,3);
psd95=spec_conf_intern5(:,4);
semilogy(fr,psd,'k')
semilogy(fr,psd50,'r-')
semilogy(fr,psd90,'r-')
semilogy(fr,psd95,'r-')
set(gca,'YLim',[0.5 300])
%
h6=subplot(3,2,6); % CMIP5 multimodel AA series - AIE-only simulatons
set(gca, 'OuterPosition', [0.48, 0.0, 0.49, 0.33])
load spec-raw-resid6.dat
load spec-conf-resid6.dat
fr=spec_raw_resid6(:,1);
psd=spec_raw_resid6(:,2);
semilogy(fr,psd,'g')
hold
load spec-raw-intern6.dat
load spec-conf-intern6.dat
fr=spec_raw_intern6(:,1);
psd=spec_raw_intern6(:,2);
psd50=spec_conf_intern6(:,2);
psd90=spec_conf_intern6(:,3);
psd95=spec_conf_intern6(:,4);
semilogy(fr,psd,'k')
semilogy(fr,psd50,'r-')
semilogy(fr,psd90,'r-')
semilogy(fr,psd95,'r-')
set(gca,'YLim',[0.5 300])





